#!/bin/sh
# gen-doc.sh
#        Copyright (C) 2002 Timo Schulz
#
# This file is part of OpenCDK.
#
# OpenCDK is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# OpenCDK is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OpenCDK; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

rm -f opencdk-api.html
cd ..
cd src
for i in `ls *.c`; do
    echo -n "creating documentation for...$i "
    ../doc/gdoc -html $i >> ../doc/opencdk-api.html
    echo "ok"
done
